LAMBDA_URI = "https://faas-sgp1-18bc02ac.doserverless.co"
LAMBDA_ENDPOINT_FOR_TICKET = "api/v1/namespaces/fn-ddfd7283-a591-4b18-8f95-7bcb178e6951/actions/ticket/api?blocking=true&result=false"
LAMBDA_AUTHEN = "Basic MDk4Y2QwNTYtYTRmZS00YTJmLWE4ZTYtYmJlMTY0ZWQ4MjdmOjVxa2RXR2JtWEh3bnBMZHl2bWg3TlQzam5ZalJpWElyRjFqVnczeklsUWZMQnBiZVpKbGdMRHFRSjZ2NXMwQ0k="
